@@ -333,13 +333,14 @@ def has_transparency(img):
 
     return False
 
-def _convert_image(src_path,output_ext,dst_path=None):
-    oext = _f.get_ext(src_path)
+def _convert_image(src_path,output_ext,dst_path=None,**kwargs):
+    # white_bg = _obj.get_kwarg(['white_bg'], False, (bool), **kwargs)
+    oext = _csu.extension(_f.get_ext(src_path))
     extension = _csu.extension(output_ext)
 
     if oext == extension:
         return src_path
-    
+
     if _f.exists(src_path) is False:
         print(f"Could not find: {src_path}")
         return False
@@ -350,15 +351,47 @@ def _convert_image(src_path,output_ext,dst_path=None):
         try:
             im = _Image.open(src_path)
             convert_to = 'RGB'
+
+
+
+
             if has_transparency(im) is True:
                 convert_to = "RGBA"
+                if oext == "png":
+                    im = png_trans_to_white(im)
+
             if extension == "jpg":
                 extension ="jpeg"
                 convert_to = "RGB"
+
+
             im = im.convert(convert_to)
+
+            # if white_bg is True:
+            #     img_w, img_h = im.size
+            #     background = _Image.new("RGB", (img_w, img_h), (255, 255, 255, 255))
+            #     background.paste(im,(0,0))
+            #     im = background
+            # im.show()
+            # exit()
             im.save(dst_path,extension)
             return dst_path
         except _UnidentifiedImageError:
             print(f"Skipping file, could not convert: {src_path}.")
             return False
 
+
+
+
+def png_trans_to_white(im):
+    im = im.convert("RGBA")
+    datas = im.getdata()
+    newData = []
+    for item in datas:
+        # print(f"item:{item}")
+        if item[3] < 10:
+            newData.append((255, 255, 255, 255))
+        else:
+            newData.append(item)
+    im.putdata(newData)
+    return im
\ No newline at end of file
