@@ -135,6 +135,8 @@ def force_list(value)->list:
     '''
 
 
+    if isinstance(value,(tuple)) is True:
+        return list(value)
     if isinstance(value,(list)) is False:
         return [value]
     return value
@@ -171,7 +173,7 @@ def count(subj:list,value:any)->int:
 
     return len([x for x in subj if x == value])
 
-def longest_string(arr:_Iterable[str])->_Iterable[int,str]:
+def longest_string(arr:_Iterable[str])->tuple:
     '''
         Get the longest string in a list.
 
